@@ -40,10 +40,9 @@ public:
         scale = static_cast<float>(fw) / w;
     }
 
-    ~GLFWWindow() override {
-        if (window != nullptr) {
-            glfwDestroyWindow(window);
-        }
+    ~GLFWWindow() override
+    {
+        if (window != nullptr) { glfwDestroyWindow(window); }
     }
 
     float scale = 1.0F;
@@ -115,14 +114,15 @@ public:
         }
     };
 
-    std::shared_ptr<Screen> init_screen(Screen::Settings const& settings) override
+    std::shared_ptr<Screen>
+    init_screen(Screen::Settings const& settings) override
     {
         glfwWindowHint(GLFW_SAMPLES, 4);
         glfwWindowHint(GLFW_COCOA_RETINA_FRAMEBUFFER, GLFW_TRUE);
         glfwWindowHint(GLFW_SCALE_TO_MONITOR, GLFW_TRUE);
         glfwWindowHint(GLFW_CONTEXT_VERSION_MAJOR, 2);
         glfwWindowHint(GLFW_CONTEXT_VERSION_MINOR, 1);
-        //glfwWindowHint(GLFW_OPENGL_FORWARD_COMPAT, GLFW_FALSE);
+        // glfwWindowHint(GLFW_OPENGL_FORWARD_COMPAT, GLFW_FALSE);
         glfwWindowHint(GLFW_OPENGL_PROFILE, GLFW_OPENGL_ANY_PROFILE);
 
         int width = settings.display_width;
@@ -151,9 +151,10 @@ public:
             fprintf(stderr, "**Error: Failed to initialize OpenGL context\n");
             return nullptr;
         }
-        // printf("GL %d.%d\n", GLAD_VERSION_MAJOR(version), GLAD_VERSION_MINOR(version));
+        // printf("GL %d.%d\n", GLAD_VERSION_MAJOR(version),
+        // GLAD_VERSION_MINOR(version));
 #endif
-        //printf("%s\n", glGetString(GL_VERSION));
+        // printf("%s\n", glGetString(GL_VERSION));
         glEnable(GL_BLEND);
         glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
         glBindFramebuffer(GL_FRAMEBUFFER, 0);
@@ -188,7 +189,6 @@ public:
 
     void mouse_was_pressed(int button, int action, int mods)
     {
-        //printf("Mouse '%x' %d\n", button, action);
         if (action == 1) {
             double x = 0;
             double y = 0;
@@ -219,7 +219,8 @@ public:
         if (key >= 0x20 && key <= 0x7f) {
             auto c = static_cast<uint32_t>(std::tolower(key));
             if (down) {
-                event_queue.emplace_back(KeyEvent{c, 0, 0});
+                event_queue.emplace_back(
+                    KeyEvent{c, static_cast<uint32_t>(mods), 0});
                 pressed.insert(c);
             }
         } else {
@@ -228,7 +229,8 @@ public:
                 auto k32 = static_cast<uint32_t>(it->second);
                 if (down) {
                     pressed.insert(k32);
-                    event_queue.emplace_back(KeyEvent{k32, 0, 0});
+                    event_queue.emplace_back(
+                        KeyEvent{k32, static_cast<uint32_t>(mods), 0});
                 }
             }
         }
