@@ -108,12 +108,17 @@ inline void add_draw_functions(pybind11::class_<T, O...>& cls)
             py::arg("size") = Vec2f{-1, -1});
     cls.def( "clear", [](T& thiz, uint32_t color) {
       context_from(thiz)->clear(color);
-    }, py::arg("color") = color::black);
+    }, py::arg("color") = color::transp);
     cls.def_property("draw_color", [](T& thiz) {
       return context_from(thiz)->fg;
     }, [](T& thiz, uint32_t color) {
       context_from(thiz)->set_color(color);
     });
+    cls.def_property("clear_mask", [](T& thiz) {
+      return context_from(thiz)->clear_mask;
+    }, [](T& thiz, uint32_t mask) {
+      context_from(thiz)->clear_mask = mask;
+    });
     cls.def_property("line_width", [](T& thiz) {
       return context_from(thiz)->line_width;
     }, [](T& thiz, float lw) {
