@@ -33,13 +33,20 @@ inline gl::TexRef image_from_vec2(Vec2f const& v)
 {
     return {static_cast<int>(v.x), static_cast<int>(v.y)};
 }
+inline gl::TexRef image_from_pixels(int width, std::vector<uint32_t> pixels)
+{
+    auto tex = std::make_shared<gl::Texture>(width, static_cast<int>(pixels.size()) / width, pixels);
+    return gl::TexRef{tex};
+}
 
 inline auto add_image_class(py::module_ const& mod)
 {
+
     // Image
     return py::class_<gl_wrap::TexRef>(mod, "Image")
         .def(py::init<int32_t, int32_t>(), py::arg("width"), py::arg("height"))
         .def(py::init<>(&image_from_vec2), py::arg("size"))
+        .def(py::init<>(&image_from_pixels), py::arg("width"), py::arg("pixels"))
         .def("split", &split_wh, py::arg("cols") = -1, py::arg("rows") = -1,
              py::arg("width") = 8, py::arg("height") = 8)
         .def("split", &split_size, py::arg("size"))
